@@ -7,6 +7,7 @@ import web
 import webint_posts
 from mf.util import discover_post_type
 from webagt import Document
+from webint_live import app
 
 __all__ = [
     "discover_post_type",
@@ -20,9 +21,11 @@ __all__ = [
     "get_posts",
     "get_categories",
     "Document",
+    "livestream",
 ]
 
 tx = web.tx
+livestream = app.view.stream
 
 
 def pformat(obj):
